aboutsummaryrefslogtreecommitdiff
path: root/src/modules/px4iofirmware
diff options
context:
space:
mode:
authorJulian Oes <julian@oes.ch>2013-09-02 17:55:27 +0200
committerJulian Oes <julian@oes.ch>2013-09-02 17:55:27 +0200
commit589ae937ee7afe5903f98f4eea25a26a79aca8f1 (patch)
treea185d7b7e8f52af1e716cae5efd3688318a2f265 /src/modules/px4iofirmware
parent38f9c25e9332cf266d38aea521a2ab9e140ec506 (diff)
downloadpx4-firmware-589ae937ee7afe5903f98f4eea25a26a79aca8f1.tar.gz
px4-firmware-589ae937ee7afe5903f98f4eea25a26a79aca8f1.tar.bz2
px4-firmware-589ae937ee7afe5903f98f4eea25a26a79aca8f1.zip
Allow mixer upload when PWM is on
Diffstat (limited to 'src/modules/px4iofirmware')
-rw-r--r--src/modules/px4iofirmware/mixer.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/modules/px4iofirmware/mixer.cpp b/src/modules/px4iofirmware/mixer.cpp
index deed25836..0edd91b24 100644
--- a/src/modules/px4iofirmware/mixer.cpp
+++ b/src/modules/px4iofirmware/mixer.cpp
@@ -358,8 +358,8 @@ static unsigned mixer_text_length = 0;
void
mixer_handle_text(const void *buffer, size_t length)
{
- /* do not allow a mixer change while outputs armed */
- if ((r_status_flags & PX4IO_P_STATUS_FLAGS_OUTPUTS_ARMED)) {
+ /* do not allow a mixer change while safety off */
+ if ((r_status_flags & PX4IO_P_STATUS_FLAGS_SAFETY_OFF)) {
return;
}